datablock AudioProfile(RetroRayGunFireSound)
{
   filename    = "./RayGunFire.wav";
   description = AudioClose3d;
   preload = true;
};

datablock AudioProfile(RetroRayGunHitSound)
{
   filename    = "./RayGunHit.wav";
   description = AudioClose3d;
   preload = true;
};

datablock ParticleData(RetroRayGunExplosionParticle)
{
	dragCoefficient      = 8;
	gravityCoefficient   = -0.5;
	inheritedVelFactor   = 0.2;
	constantAcceleration = 0.0;
	lifetimeMS           = 200;
	lifetimeVarianceMS   = 100;
	textureName          = "base/data/particles/cloud";
	spinSpeed		= 10.0;
	spinRandomMin		= -50.0;
	spinRandomMax		= 50.0;
	colors[0]     = "1 1 1 0.9";
	colors[1]     = "1 1 1 0";
	sizes[0]      = 0.15;
	sizes[1]      = 0.25;

	useInvAlpha = true;
};
datablock ParticleEmitterData(RetroRayGunExplosionEmitter)
{
   ejectionPeriodMS = 2;
   periodVarianceMS = 2;
   ejectionVelocity = 2;
   velocityVariance = 1.0;
   ejectionOffset   = 0.0;
   thetaMin         = 89;
   thetaMax         = 90;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "retroRayGunExplosionParticle";

   useEmitterColors = true;
   uiName = "";
};

datablock ExplosionData(retroRayGunExplosion)
{
   explosionShape = "./raygunExplosion.dts";
	soundProfile = RetroRayGunHitSound;

   lifeTimeMS = 70;

   particleEmitter = retroRayGunExplosionEmitter;
   particleDensity = 5;
   particleRadius = 0.2;

   emitter[0] = retroRayGunExplosionEmitter;

   faceViewer     = true;
   explosionScale = "1.5 1.5 1.5";

   shakeCamera = false;
   camShakeFreq = "10.0 11.0 10.0";
   camShakeAmp = "1.0 1.0 1.0";
   camShakeDuration = 0.5;
   camShakeRadius = 10.0;

   // Dynamic light
   lightStartRadius = 0;
   lightEndRadius = 2;
   lightStartColor = "1 0 0";
   lightEndColor = "0 0 0";
};


AddDamageType("RetroRayGun",   '<bitmap:add-ons/Weapon_RetroRayGun/CI_retroraygun> %1',    '%2 <bitmap:add-ons/Weapon_RetroRayGun/CI_retroraygun> %1',0.2,1);
datablock ProjectileData(RetroRayGunProjectile)
{
   projectileShapeName = "./raygunProjectile.dts";
   directDamage        = 50;
   directDamageType    = $DamageType::RetroRayGun;
   radiusDamageType    = $DamageType::RetroRayGun;

   brickExplosionRadius = 0;
   brickExplosionImpact = false;          //destroy a brick if we hit it directly?
   brickExplosionForce  = 10;
   brickExplosionMaxVolume = 1;          //max volume of bricks that we can destroy
   brickExplosionMaxVolumeFloating = 2;  //max volume of bricks that we can destroy if they aren't connected to the ground

   impactImpulse	     = 400;
   verticalImpulse	  = 400;
   explosion           = retroRayGunExplosion;
   particleEmitter     = ""; //bulletTrailEmitter;

   muzzleVelocity      = 55;
   velInheritFactor    = 0;

   armingDelay         = 0;
   lifetime            = 4000;
   fadeDelay           = 3500;
   bounceElasticity    = 0.5;
   bounceFriction      = 0.20;
   isBallistic         = false;
   gravityMod = 0.0;

   hasLight    = true;
   lightRadius = 3.0;
   lightColor  = "1 0 0";

   uiName = "Ray Gun Laser";
};

//////////
// item //
//////////
datablock ItemData(RetroRayGunItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./raygun.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Ray Gun";
	iconName = "./icon_retroraygun";
	doColorShift = true;
	colorShiftColor = "1.0 0.0 0.0 1.0";

	 // Dynamic properties defined by the scripts
	image = retroRayGunImage;
	canDrop = true;
};

////////////////
//weapon image//
////////////////
datablock ShapeBaseImageData(RetroRayGunImage)
{
   // Basic Item properties
   shapeFile = "./raygun.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;
   offset = "0 0 0";
   eyeOffset = 0; //"0.7 1.2 -0.5";
   rotation = eulerToMatrix( "0 0 0" );

   // When firing from a point offset from the eye, muzzle correction
   // will adjust the muzzle vector to point to the eye LOS point.
   // Since this weapon doesn't actually fire from the muzzle point,
   // we need to turn this off.  
   correctMuzzleVector = true;

   // Add the WeaponImage namespace as a parent, WeaponImage namespace
   // provides some hooks into the inventory system.
   className = "WeaponImage";

   // Projectile && Ammo.
   item = BowItem;
   ammo = " ";
   projectile = retroRayGunProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = false;
   //raise your arm up or not
   armReady = true;
   minShotTime = 400;  

   doColorShift = true;
   colorShiftColor = retroRayGunItem.colorShiftColor;

   //casing = " ";

   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.15;
	stateTransitionOnTimeout[0]       = "Ready";
	stateSound[0]					= weaponSwitchSound;

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "Fire";
	stateAllowImageChange[1]         = true;
	stateSequence[1]	= "Ready";

	stateName[2]                    = "Fire";
	stateTransitionOnTimeout[2]     = "Smoke";
	stateTimeoutValue[2]            = 0.14;
	stateFire[2]                    = true;
	stateAllowImageChange[2]        = false;
	stateSequence[2]                = "Fire";
	stateScript[2]                  = "onFire";
	stateWaitForTimeout[2]			= true;
	stateEmitter[2]					= gunFlashEmitter;
	stateEmitterTime[2]				= 0.05;
	stateEmitterNode[2]				= "muzzleNode";
	stateSound[2]					= RetroRayGunFireSound;
	stateEjectShell[2]       = true;

	stateName[3] = "Smoke";
	stateEmitter[3]					= gunSmokeEmitter;
	stateEmitterTime[3]				= 0.05;
	stateEmitterNode[3]				= "muzzleNode";
	stateTimeoutValue[3]            = 0.01;
	stateTransitionOnTimeout[3]     = "CoolDown";

        stateName[4] = "CoolDown";
        stateTimeoutValue[4]            = 0.3;
	stateTransitionOnTimeout[4]     = "Reload";
        stateSequence[4]                = "Ready";

	stateName[5]			= "Reload";
	stateSequence[5]                = "Reload";
	stateTransitionOnTriggerUp[5]     = "Ready";
	stateSequence[5]	= "Ready";

};

function RetroRayGunImage::onFire(%this,%obj,%slot)
{
	if(%obj.getDamagePercent() < 1.0)
		%obj.playThread(2, shiftAway);
	Parent::onFire(%this,%obj,%slot);	
}
